@@ -185,7 +185,7 @@ eog_exif_set_label (GtkWidget *w, ExifData *exif_data, gint tag_id)
 	gchar *label_text = NULL;
 
 	if (exif_data) {
-		buf_ptr = eog_exif_util_get_value (exif_data, tag_id,
+		buf_ptr = eog_exif_data_get_value (exif_data, tag_id,
 						   exif_buffer, 512);
 
 		if (tag_id == EXIF_TAG_DATE_TIME_ORIGINAL && buf_ptr)
@@ -781,6 +781,17 @@ eog_properties_dialog_init (EogPropertiesDialog *prop_dlg)
 #endif
 }
 
+/**
+ * eog_properties_dialog_new:
+ * @parent: 
+ * @thumbview: 
+ * @next_image_action: 
+ * @previous_image_action: 
+ *
+ * 
+ *
+ * Returns: (transfer full) (type EogPropertiesDialog): a new #EogPropertiesDialog
+ **/
 GObject *
 eog_properties_dialog_new (GtkWindow    *parent,
 			   EogThumbView *thumbview,
